| [ Web Proxy ] |
| Viewing: https://raw.githubusercontent.com/ModuleWorks/taskflow/task_isolation/docs/SingleTaskCUDA.html | [Back] [Original] |
tf::cudaFlow provides a template method, tf::cudaFlow::single_task, for creating a task to run the given callable using a single kernel thread.
You need to include the header file, taskflow/cuda/algorithm/for_each.hpp, for creating a single-threaded task.
#include <taskflow/cuda/algorithm/for_each.hpp>
You can create a task to run a kernel function just once, i.e., using one GPU thread. This is handy when you want to set up a single or a few global variables that do not need multiple threads and will be used by multiple kernels afterwards. The following example creates a single-task kernel that sets a device variable to 1.
int* gpu_variable; cudaMalloc(&gpu_variable, sizeof(int)); tf::cudaFlow cf; cf.single_task([gpu_variable] __device__ () { *gpu_Variable = 1; }); tf::cudaStream stream; cf.run(stream); stream.synchronize();
Since the callable runs on GPU, it must be declared with a __device__ specifier.
The single-task algorithm is also available in tf::cudaFlowCapturer::single_task.
Search for symbols, directories, files, pages or
modules. You can omit any prefix from the symbol or file path; adding a
: or / suffix lists all members of given symbol or
directory.
Use ↓ / ↑ to navigate through the list, Enter to go. Tab autocompletes common prefix, you can copy a link to the result using L while M produces a Markdown link.
Taskflow handbook is part of the Taskflow project, copyright Dr. Tsung-Wei Huang, 2018–2025.
Generated by Doxygen 1.12.0 and m.css.
| Web Proxy Viewer | New URL | Original Page |